@@ -132,7 +132,7 @@ watch_ssh_process (GPid pid, gint status, SeahorseSSHOperation *sop)
         /* Was killed */
         if (!WIFEXITED (status)) {
             seahorse_operation_mark_done (SEAHORSE_OPERATION (sop), FALSE, 
-                g_error_new (SEAHORSE_ERROR, 0, _("The ssh command was terminated unexpectedly.")));
+                g_error_new (SEAHORSE_ERROR, 0, _("The SSH command was terminated unexpectedly.")));
             
         /* Command failed */
         } else if (WEXITSTATUS (status) != 0) {
@@ -694,14 +694,14 @@ seahorse_ssh_operation_sync (SeahorseSSHSource *ssrc, const gchar *command,
     
     if (!WIFEXITED (status)) {
         g_critical ("SSH command didn't exit properly: %s", command);
-        g_set_error (error, SEAHORSE_ERROR, 0, "%s", _("The ssh command was terminated unexpectedly."));
+        g_set_error (error, SEAHORSE_ERROR, 0, "%s", _("The SSH command was terminated unexpectedly."));
         g_free (sout);
         g_free (serr);
         return NULL;
     }
     
     if (WEXITSTATUS (status) != 0) {
-        g_set_error (error, SEAHORSE_ERROR, 0, "%s", _("The ssh command failed."));
+        g_set_error (error, SEAHORSE_ERROR, 0, "%s", _("The SSH command failed."));
         g_warning ("SSH command failed: %s (%d)", command, WEXITSTATUS (status));
         if (serr && serr[0])
             g_warning ("SSH error output: %s", serr);
@@ -887,8 +887,8 @@ generate_password_cb (SeahorseSSHOperation *sop, const gchar* msg)
 
     /* If the first time then prompt */
     if (!pv->prompt_dialog) {
-        return prompt_passphrase (sop, _("New Secure Shell Key Passphrase"), 
-                _("Enter a passphrase for your new SSH key."), NULL, TRUE);
+        return prompt_passphrase (sop, _("Passphrase for New Secure Shell Key"), 
+                _("Enter a passphrase for your new Secure Shell key."), NULL, TRUE);
     }
     
     /* Otherwise return the entered passphrase */
