@@ -18,13 +18,14 @@
  * 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
- 
+
+#include <config.h> 
 #include <gnome.h>
  
 #include "seahorse-gpgmex.h"
 #include "seahorse-key-dialogs.h"
 #include "seahorse-key-widget.h"
-#include "seahorse-key-op.h"
+#include "seahorse-pgp-key-op.h"
 #include "seahorse-util.h"
 
 #define EXPIRES "expires"
@@ -66,7 +67,7 @@ static void
 ok_clicked (GtkButton *button, SeahorseWidget *swidget)
 {
 	SeahorseKeyWidget *skwidget;
-	SeahorseKeyType real_type;
+	SeahorseKeyEncType real_type;
 	guint type, length;
 	time_t expires;
 	gpgme_error_t err;
@@ -102,26 +103,26 @@ ok_clicked (GtkButton *button, SeahorseWidget *swidget)
 	
 	widget = glade_xml_get_widget (swidget->xml, swidget->name);
 	gtk_widget_set_sensitive (widget, FALSE);
-	err = seahorse_key_pair_op_add_subkey (SEAHORSE_KEY_PAIR (skwidget->skey), 
+	err = seahorse_pgp_key_pair_op_add_subkey (SEAHORSE_PGP_KEY (skwidget->skey), 
                                            real_type, length, expires);
 	gtk_widget_set_sensitive (widget, TRUE);
 	
 	if (!GPG_IS_OK (err))
 		seahorse_util_handle_gpgme (err, _("Couldn't add subkey"));
-	else
-		seahorse_widget_destroy (swidget);
+
+	seahorse_widget_destroy (swidget);
 }
 
 void
-seahorse_add_subkey_new (SeahorseContext *sctx, SeahorseKey *skey)
+seahorse_add_subkey_new (SeahorsePGPKey *pkey)
 {
 	SeahorseWidget *swidget;
     gchar *userid;
 	
-	swidget = seahorse_key_widget_new ("add-subkey", sctx, skey);
+	swidget = seahorse_key_widget_new ("add-subkey", SEAHORSE_KEY (pkey));
 	g_return_if_fail (swidget != NULL);
 	
-    userid = seahorse_key_get_userid (skey, 0);
+    userid = seahorse_key_get_name (SEAHORSE_KEY (pkey), 0);
 	gtk_window_set_title (GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)),
 		g_strdup_printf (_("Add subkey to %s"), userid));
     g_free (userid);
