@@ -61,7 +61,7 @@ enum {
 
 struct _SeahorseGKeyringSourcePrivate {
     SeahorseMultiOperation *operations;     /* A list of all current operations */    
-    gchar *keyring_name;                    /* The keyring name */
+    gchar *keyring_name;                    /* The key ring name */
 };
 
 G_DEFINE_TYPE (SeahorseGKeyringSource, seahorse_gkeyring_source, SEAHORSE_TYPE_KEY_SOURCE);
@@ -93,12 +93,12 @@ DECLARE_OPERATION (List, list)
     guint total;
     
     guint32 current_id;
+    guint32 info_flags;
     GnomeKeyringItemInfo *current_info;
     GnomeKeyringAttributeList *current_attrs;
     
     gpointer request;
     
-    SeahorseKeySourceLoad mode;
     GHashTable *checks;
 
 END_DECLARE_OPERATION
@@ -248,6 +248,10 @@ remove_key_from_context (gpointer kt, SeahorseKey *dummy, SeahorseKeySource *sks
 static void
 process_next_item (SeahorseListOperation *lop)
 {
+    g_assert (lop);
+    g_assert (SEAHORSE_IS_GKEYRING_SOURCE (lop->gsrc));
+    g_assert (lop->gsrc->pv->keyring_name != NULL);
+
     seahorse_operation_mark_progress_full (SEAHORSE_OPERATION (lop), NULL, 
                                            lop->total - g_list_length (lop->remaining), 
                                            lop->total);
@@ -287,8 +291,19 @@ process_next_item (SeahorseListOperation *lop)
     lop->remaining = g_list_delete_link (lop->remaining, lop->remaining);
     
     g_assert (!lop->request);
+
+	/* 
+	 * Check for the new gnome_keyring_item_get_info_full() function. 
+ 	 * TODO: Once this is in a stable release of gnome-keyring, remove defs.
+ 	 */
+#ifdef GNOME_KEYRING_ITEM_INFO_ALL
+    lop->request = gnome_keyring_item_get_info_full (lop->gsrc->pv->keyring_name, 
+                                lop->current_id, lop->info_flags, 
+                                (GnomeKeyringOperationGetItemInfoCallback)item_info_ready, lop, NULL);
+#else
     lop->request = gnome_keyring_item_get_info (lop->gsrc->pv->keyring_name, 
                 lop->current_id, (GnomeKeyringOperationGetItemInfoCallback)item_info_ready, lop, NULL);
+#endif
 }
 
 static void 
@@ -312,10 +327,13 @@ keyring_ids_ready (GnomeKeyringResult result, GList *list, SeahorseListOperation
 }
 
 static SeahorseListOperation*
-start_list_operation (SeahorseGKeyringSource *gsrc, SeahorseKeySourceLoad mode, 
-                      GQuark keyid)
+start_list_operation (SeahorseGKeyringSource *gsrc, GQuark keyid)
 {
     SeahorseListOperation *lop;
+    GList *keys, *l;
+
+    g_assert (SEAHORSE_IS_GKEYRING_SOURCE (gsrc));
+    g_assert (gsrc->pv->keyring_name);
 
     lop = g_object_new (SEAHORSE_TYPE_LIST_OPERATION, NULL);
     lop->gsrc = gsrc;
@@ -323,7 +341,7 @@ start_list_operation (SeahorseGKeyringSource *gsrc, SeahorseKeySourceLoad mode,
     seahorse_operation_mark_start (SEAHORSE_OPERATION (lop));
     
     /* When we know which key to load go directly to step two */
-    if (mode == SKSRC_LOAD_KEY) {
+    if (keyid) {
         guint32 id;
         
         id = parse_keyid (keyid);
@@ -331,6 +349,11 @@ start_list_operation (SeahorseGKeyringSource *gsrc, SeahorseKeySourceLoad mode,
         
         lop->remaining = g_list_prepend (lop->remaining, GUINT_TO_POINTER (id));
         lop->total = 1;
+
+#ifdef GNOME_KEYRING_ITEM_INFO_ALL
+        /* TODO: Once this is in a stable release of gnome-keyring, remove defs. */
+        lop->info_flags = GNOME_KEYRING_ITEM_INFO_ALL;
+#endif
         
         seahorse_operation_mark_progress (SEAHORSE_OPERATION (lop), _("Retrieving key"), -1);
         process_next_item (lop);
@@ -338,17 +361,12 @@ start_list_operation (SeahorseGKeyringSource *gsrc, SeahorseKeySourceLoad mode,
     }
     
     /* When loading new keys prepare a list of current */
-    if (mode == SKSRC_LOAD_NEW) {
-        GList *keys, *l;
-
-        lop->checks = g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL, NULL);
-        keys = seahorse_context_get_keys (SCTX_APP (), SEAHORSE_KEY_SOURCE (gsrc));
-        for (l = keys; l; l = g_list_next (l))
-            g_hash_table_insert (lop->checks, GUINT_TO_POINTER (seahorse_key_get_keyid (l->data)), 
-                                         GUINT_TO_POINTER (TRUE));
-        g_list_free (keys);
-    }
-    
+    lop->checks = g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL, NULL);
+    keys = seahorse_context_get_keys (SCTX_APP (), SEAHORSE_KEY_SOURCE (gsrc));
+    for (l = keys; l; l = g_list_next (l))
+        g_hash_table_insert (lop->checks, GUINT_TO_POINTER (seahorse_key_get_keyid (l->data)), 
+                             GUINT_TO_POINTER (TRUE));
+    g_list_free (keys);
     
     /* Start listing of ids */
     seahorse_operation_mark_progress (SEAHORSE_OPERATION (lop), _("Listing passwords"), -1);
@@ -434,8 +452,7 @@ key_changed (SeahorseKey *skey, SeahorseKeyChange change, SeahorseKeySource *sks
     if (change == SKEY_CHANGE_ALL)
         return;
 
-    seahorse_key_source_load_async (sksrc, SKSRC_LOAD_KEY, 
-                                    seahorse_key_get_keyid (skey), NULL);
+    seahorse_key_source_load_async (sksrc, seahorse_key_get_keyid (skey));
 }
 
 static void
@@ -454,17 +471,19 @@ init_keyring_name (SeahorseGKeyringSource *gsrc, GError **err)
     if (gsrc->pv->keyring_name)
         return TRUE;
 
-    /* Get default keyring name when no other keyring has been specified */
+    /* Get default key ring name when no other key ring has been specified */
     res = gnome_keyring_get_default_keyring_sync (&(gsrc->pv->keyring_name));
     if (res != GNOME_KEYRING_RESULT_OK)
-        g_warning ("couldn't get default keyring: (code %d)", res);
+        g_warning ("couldn't get default gnome-keyring keyring: (code %d)", res);
     
     ret = seahorse_gkeyring_operation_parse_error (res, err);
     if(!ret)
         return FALSE;
     
-    /* Hmmm, this happens sometimes, need to figure out why */
-    g_return_val_if_fail (gsrc->pv->keyring_name != NULL, FALSE);
+    /* Happens when user has not yet initialized a key ring */
+    if (!gsrc->pv->keyring_name)
+        g_message ("no default gnome-keyring key ring found");
+
     return TRUE;
 }
 
@@ -528,8 +547,7 @@ seahorse_gkeyring_source_set_property (GObject *object, guint prop_id, const GVa
 }
 
 static SeahorseOperation*
-seahorse_gkeyring_source_load (SeahorseKeySource *src, SeahorseKeySourceLoad mode,
-                               GQuark keyid, const gchar *match)
+seahorse_gkeyring_source_load (SeahorseKeySource *src, GQuark keyid)
 {
     SeahorseGKeyringSource *gsrc;
     SeahorseListOperation *lop;
@@ -538,16 +556,14 @@ seahorse_gkeyring_source_load (SeahorseKeySource *src, SeahorseKeySourceLoad mod
     g_assert (SEAHORSE_IS_KEY_SOURCE (src));
     gsrc = SEAHORSE_GKEYRING_SOURCE (src);
     
-    /* Don't support searching */
-    if (mode == SKSRC_LOAD_SEARCH)
-        return seahorse_operation_new_complete (NULL);
-
     if (!init_keyring_name (gsrc, &err))
         return seahorse_operation_new_complete (err);
 
-    g_assert (gsrc->pv->keyring_name);
+    /* No keyring, act as if no items */
+    if (!gsrc->pv->keyring_name) 
+        return seahorse_operation_new_complete (NULL);
 
-    lop = start_list_operation (gsrc, mode, keyid);
+    lop = start_list_operation (gsrc, keyid);
     seahorse_multi_operation_take (gsrc->pv->operations, SEAHORSE_OPERATION (lop));
     
     g_object_ref (lop);
@@ -621,14 +637,16 @@ seahorse_gkeyring_source_remove (SeahorseKeySource *sksrc, SeahorseKey *skey,
     if (!init_keyring_name (gsrc, err))
         return FALSE;
 
-    g_assert (gsrc->pv->keyring_name);
+    /* No keyring, act as if deleted */
+    if (!gsrc->pv->keyring_name) 
+        return TRUE;
     
     res = gnome_keyring_item_delete_sync (gsrc->pv->keyring_name, git->item_id);
     ret = seahorse_gkeyring_operation_parse_error (res, err);
     
     if (ret) {
         seahorse_context_remove_key (SCTX_APP (), skey);
-        seahorse_key_source_load_async (sksrc, SKSRC_LOAD_NEW, 0, NULL);
+        seahorse_key_source_load_async (sksrc, 0);
     }
     
     return ret;
